@@ -3,7 +3,7 @@
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 
-"""See :doc:`/specs/ana`.
+"""See :doc:`/plugins/ana`.
 
 """
 
@@ -18,7 +18,7 @@ class Plugin(ad.Plugin):
     """
     The `max_length` of the `Reference` field of an account.
     """
-    
+
     def setup_config_menu(self, site, user_type, m):
         mg = site.plugins.ledger
         m = m.add_menu(mg.app_label, mg.verbose_name)
@@ -40,4 +40,3 @@ class Plugin(ad.Plugin):
         m = m.add_menu(mg.app_label, mg.verbose_name)
         m.add_action('ana.Invoices')
         # m.add_action('ana.InvoiceItems')
-
