@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2022 Rumma & Ko Ltd
+# Copyright 2009-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import datetime
@@ -15,7 +15,9 @@ from django.utils import timezone
 from lino.api import dd, rt
 from lino import mixins
 from lino.core import constants
-from lino.core.gfks import gfk2lookup
+from lino.core.gfks import gfk2lookup, ContentType
+from lino.modlib.uploads.mixins import UploadBase
+from lino.core.utils import models_by_base
 from lino.modlib.gfks.mixins import Controllable
 from lino_xl.lib.topics.models import AddInterestField
 from lino.modlib.users.mixins import My, UserAuthored
@@ -132,14 +134,22 @@ class Entry(UserAuthored, Controllable, CombinedDateTime,
         return self.get_item_preview(ar)
 
     def get_primary_image(self):
-        FileUsage = rt.models.albums.FileUsage
-        qs = FileUsage.objects.filter(
-            **gfk2lookup(FileUsage.owner, self), primary_image=True)
-        return qs.first()
+        Mention = rt.models.memo.Mention
+        # stypes = [ContentType.objects.get_for_model(m)
+        #     for m in models_by_base(UploadBase)]
+        # qs = Mention.objects.filter(**gfk2lookup(
+        #     Mention.owner, self, source_type__in=stypes))
+        file_type = ContentType.objects.get_for_model(rt.models.albums.File)
+        qs = Mention.objects.filter(**gfk2lookup(
+            Mention.owner, self, source_type=file_type))
+            # Mention.owner, self, source_type__in=stypes))
+        for obj in qs:
+            if obj.source.file is not None:
+                return obj.source
 
     def as_page(self, ar):
         title = self.title or self
-        img = self.get_primary_image()
+        # img = self.get_primary_image()
         pub_info = _("Published {date} by {author}").format(
             date=self.pub_date.isoformat(),
             author=tostring(ar.obj2html(self.user)))
@@ -151,13 +161,13 @@ class Entry(UserAuthored, Controllable, CombinedDateTime,
 
         yield """<div style="max-width: 80ch; margin: auto">"""
         yield "<h2>{}</h2>".format(title)
-        if img is not None:
-            yield """
-            <p><figure>
-            {img.thumbnail_large}
-            <figcaption style="text-align: center;">{img.description}</figcaption>
-            </figure></p>
-            """.format(img=img.file, obj=self)
+        # if img is not None:
+        #     yield """
+        #     <p><figure>
+        #     {img.thumbnail_large}
+        #     <figcaption style="text-align: center;">{img.description}</figcaption>
+        #     </figure></p>
+        #     """.format(img=img, obj=self)
         yield """<span><em>{}</em></span>""".format(pub_info)
         yield """<hr/>"""
         yield self.body_full_preview
@@ -172,8 +182,7 @@ class Entry(UserAuthored, Controllable, CombinedDateTime,
         s += """<span style="font-size:70%;"><em>{}</em></span></a>""".format(pub_info)
         s += """<div style="display:flex;">"""
         if img is not None:
-            s += """<div><a href="{url}">{img.thumbnail}</a></div>""".format(
-                img=img.file, url=url)
+            s += f"""<div><a href="{url}">{img.thumbnail}</a></div>"""
         else:
             s += """<div>no image</div>"""
         s += """<div style="margin-left:20px;"><p style="text-align:justify;">"""
@@ -235,8 +244,8 @@ class EntryDetail(dd.DetailLayout):
     # summary
     pub_date pub_time user:10 language:10 owner add_interest"""
 
-    if dd.is_installed('albums'):
-        main += "\nalbums.UsagesByController"
+    # if dd.is_installed('albums'):
+    #     main += "\nalbums.UsagesByController"
 
     main += "\nbody:60 topics.InterestsByController:20 comments.CommentsByRFC:20 #TaggingsByEntry:20"
 
