@@ -26,6 +26,7 @@ from lino.mixins import Referrable, Draggable
 from lino.utils.quantities import Duration
 from lino.modlib.checkdata.choicelists import Checker
 from lino.modlib.gfks.mixins import Controllable
+from lino.modlib.memo.mixins import MemoReferrable
 from lino.modlib.notify.api import send_notification
 from lino.modlib.printing.mixins import TypedPrintable
 from lino.modlib.printing.mixins import Printable
@@ -327,8 +328,8 @@ class EntryRepeater(RecurrenceSet, EventGenerator):
 
     class Meta:
         app_label = 'cal'
-        verbose_name = _("Cal entry repeater")
-        verbose_name_plural = _("Cal entry repeaters")
+        verbose_name = _("Calendar entry repeater")
+        verbose_name_plural = _("Calendar entry repeaters")
         abstract = dd.is_abstract_model(__name__, 'EntryRepeater')
 
     cal_entry = dd.ForeignKey('cal.Event', related_name='repeaters')
@@ -409,7 +410,7 @@ class ExtAllDayField(dd.VirtualField):
 
 class Event(
     Component, Ended, Assignable, TypedPrintable, Mailable, Postable,
-    Publishable, GoogleCalendarEventSynchronized, Draggable):
+    Publishable, GoogleCalendarEventSynchronized, Draggable, MemoReferrable):
 
     class Meta:
         app_label = 'cal'
@@ -420,6 +421,8 @@ class Event(
         # verbose_name = pgettext("cal", "Event")
         # verbose_name_plural = pgettext("cal", "Events")
 
+    memo_command = 'cal_entry'
+
     publisher_location = "cal"
     publisher_page_template = "cal/event.pub.html"
 
@@ -1410,17 +1413,17 @@ if False:  # removed 20160610 because it is probably not used
     def pre_analyze(sender, **kw):
         sender.user_model.define_action(update_reminders=UpdateUserReminders())
 
-@dd.receiver(dd.post_startup)
-def setup_memo_commands(sender=None, **kwargs):
-    # See :doc:`/specs/memo`
-
-    if not sender.is_installed('memo'):
-        return
-
-    mp = sender.plugins.memo.parser
-
-    mp.register_django_model('cal_event', rt.models.cal.Event,
-        rnd=lambda obj: f"[cal_event {obj.id} {obj.summary}]",
-        title=lambda obj: obj.summary)
+# @dd.receiver(dd.post_startup)
+# def setup_memo_commands(sender=None, **kwargs):
+#     # See :doc:`/specs/memo`
+#
+#     if not sender.is_installed('memo'):
+#         return
+#
+#     mp = sender.plugins.memo.parser
+#
+#     mp.register_django_model('cal_event', rt.models.cal.Event,
+#         rnd=lambda obj: f"[cal_event {obj.id} {obj.summary}]",
+#         title=lambda obj: obj.summary)
 
 from .ui import *
