@@ -867,7 +867,10 @@ class MonthlySlave(ParameterClone, MonthlySlaveBase, DaysTable):
     @classmethod
     def param_defaults(cls, ar, **kw):
         kw = super(MonthlySlave, cls).param_defaults(ar, **kw)
-        kw.update(user=ar.get_user())
+        u = ar.get_user()
+        if u.is_anonymous:
+            raise Exception("20230113")
+        kw.update(user=u)
         return kw
 
 
