@@ -47,12 +47,12 @@ class Plugin(ad.Plugin):
         if site.plugins.contacts.use_vcard_export:
             yield 'vobject'
 
-    def post_site_startup(self, site):
-        if not site.is_installed('memo'):
-            return
-        rdm = site.plugins.memo.parser.register_django_model
-        rdm('person', site.models.contacts.Person)
-        rdm('company', site.models.contacts.Company)
+    # def post_site_startup(self, site):
+    #     if not site.is_installed('memo'):
+    #         return
+    #     rdm = site.plugins.memo.parser.register_django_model
+    #     rdm('person', site.models.contacts.Person)
+    #     rdm('company', site.models.contacts.Company)
 
     def setup_main_menu(self, site, user_type, m):
         m = m.add_menu(self.app_label, self.verbose_name)
