@@ -1,9 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2013-2014 Rumma & Ko Ltd
+# Copyright 2013-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
-"""
-"""
-from __future__ import unicode_literals
 
 from lino.api import dd, rt
 from lino.utils import i2d
@@ -54,20 +51,23 @@ def objects():
     breitensport = Type(
         name="Breitensport",
         name_nl="Sport voor allen",
-        name_fr="Sport pour tous")
+        name_fr="Sport pour tous",
+        name_en="Sport for everybody")
     yield breitensport
 
     strasse = Type(
         name="Radrennen Straße",
         name_nl="Koersen op de weg",
         name_fr="Courses sur route",
+        name_en="Road races",
         events_column_names="where:40 when:40")
     yield strasse
 
     mtb = Type(
         name="MTB Rennen ≥ 15-jährige",
         name_nl="MTB koersen ≥ 15 jaarige",
-        name_fr="Courses Mountain Bike pour ≥ 15 ans")
+        name_fr="Courses Mountain Bike pour ≥ 15 ans",
+        name_en="Off-road races (≥ 15 years)")
     yield mtb
 
     trophy = Type(
@@ -138,13 +138,13 @@ def objects():
     # 2013
 
     yield event(breitensport, 20130324,
-                "18\. Bike-Day  IRMEP-RSK Eupen",
-                "18\. Bike-Day  IRMEP-RSK Eupen",
+                "18. Bike-Day  IRMEP-RSK Eupen",
+                "18. Bike-Day  IRMEP-RSK Eupen",
                 "18e Bike-Day de l'IRMEP-RSK Eupen",
                 f1, f2, place=irmep)
     yield event(breitensport, 20130505,
-                "24\. Eifel-Biker event",
-                "24\. Eifel-Biker event",
+                "24. Eifel-Biker event",
+                "24. Eifel-Biker event",
                 "24e event des Eifel-Bikers",
                 f1, f2, place=domaine)
     yield event(breitensport, 20130706,
@@ -159,14 +159,14 @@ def objects():
                 place=galmei, url="http://www.vclc.be")
 
     yield event(strasse, 20130510,
-                "1\. Etappe des Triptyque Ardennais",
-                "1\. etappe Triptyque Ardennais",
+                "1. Etappe des Triptyque Ardennais",
+                "1. etappe Triptyque Ardennais",
                 "1e étape du Triptyque Ardennais",
                 cities=["Raeren", "Büllingen"])
 
     yield event(strasse, 20130511,
-                "2\. Etappe des Triptyque Ardennais",
-                "2\. etappe Triptyque Ardennais",
+                "2. Etappe des Triptyque Ardennais",
+                "2. etappe Triptyque Ardennais",
                 "2e étape du Triptyque Ardennais",
                 cities=["Monschau", "Eupen"])
 
@@ -207,13 +207,13 @@ def objects():
       #~ cities=["Ouren"])
 
     yield event(breitensport, 20140323,
-                "19\. Bike-Day  IRMEP-RSK Eupen",
-                "19\. Bike-Day  IRMEP-RSK Eupen",
+                "19. Bike-Day  IRMEP-RSK Eupen",
+                "19. Bike-Day  IRMEP-RSK Eupen",
                 "19e Bike-Day de l'IRMEP-RSK Eupen",
                 f1, f2, f4, place=irmep)
     yield event(breitensport, 20140504,
-                "25\. Eifel-Biker event",
-                "25\. Eifel-Biker event",
+                "25. Eifel-Biker event",
+                "25. Eifel-Biker event",
                 "25e event des Eifel-Bikers",
                 f1, f2, f4, place=domaine)
                 # url="http://www.eifel-biker.be")
@@ -226,19 +226,19 @@ def objects():
     yield event(breitensport, 20140518,
                 "Radtag der DG",
                 "Fietsdag van de DG",
-                "Journée vélo de la CG", f3, f2,  
+                "Journée vélo de la CG", f3, f2,
                 place=galmei, url="")
 
     yield event(strasse, 20140523,
-                "1\. Etappe des Triptyque Ardennais",
-                "1\. etappe Triptyque Ardennais",
+                "1. Etappe des Triptyque Ardennais",
+                "1. etappe Triptyque Ardennais",
                 "1e étape du Triptyque Ardennais",
                 cities=["Kelmis", "Büllingen", "Raeren"])
                 # url="http://www.cchawy.be/")
 
     yield event(strasse, 20140524,
-                "2\. Etappe des Triptyque Ardennais",
-                "2\. etappe Triptyque Ardennais",
+                "2. Etappe des Triptyque Ardennais",
+                "2. etappe Triptyque Ardennais",
                 "2e étape du Triptyque Ardennais",
                 cities=["Bütgenbach", "Eupen", "Lontzen"])
                 # url="http://www.cchawy.be/")
