@@ -180,6 +180,11 @@ class Journal(BabelNamed, Sequenced, Referrable, PrintableType):
     #     pass
     #
     def full_clean(self, *args, **kw):
+
+        # super() must come first to make sure all fields have been converted to
+        # their type:
+        super().full_clean(*args, **kw)
+
         if self.dc is None:
             if self.trade_type:
                 self.dc = self.trade_type.dc
@@ -198,7 +203,6 @@ class Journal(BabelNamed, Sequenced, Referrable, PrintableType):
                 raise ValidationError(tpl.format(
                     self, self.voucher_type.model, dd.plugins.invoicing.voucher_model))
 
-        super().full_clean(*args, **kw)
 
 
     def disable_voucher_delete(self, doc):
@@ -877,7 +881,7 @@ class RegistrableVoucher(Registrable, Voucher):
             # raise Exception("20191223 {} is not in {}".format(self.state, dd.plugins.ledger.registered_states))
             return "({0} #{1})".format(self._meta.verbose_name, self.id)
             # return "{0} #{1}".format(self.journal.ref, self.id)
-        return super(RegistrableVoucher, self).__str__()
+        return super().__str__()
 
     def after_state_change(self, ar, oldstate, newstate):
         # Movements are created *after* having changed the state because
