@@ -7,7 +7,7 @@ from measurement.measures import Distance, Area, Volume, Mass, Time
 
 __all__ = [
     'TimeUnits', 'WeightUnits', 'DistanceUnits', 'AreaUnits', 'VolumeUnits',
-    'UnitTypes'
+    'UnitTypes', 'AllUnits', 'MeasurablesUnits'
 ]
 
 ALL_UNITS = dict(
@@ -18,15 +18,28 @@ ALL_UNITS = dict(
     VolumeUnits=Volume
 )
 
+class BaseUnit(dd.Choice):
+    measurement_name = None
 
 class Units(dd.ChoiceList):
     verbose_name = _("Unit")
     verbose_name_plural = _("Units")
+    item_class = BaseUnit
 
+class Unit(BaseUnit):
+    choicelist_class = None
 
-for choicelist, measurement in ALL_UNITS.items():
-    locals()[choicelist] = type(choicelist, (Units, ), {})
-    add = locals()[choicelist].add_item
+class MeasurablesUnits(Units):
+    item_class = Unit
+
+class AllUnits(Units):
+    item_class = Unit
+    verbose_name_plural = _("All units")
+
+for choicelist_name, measurement in ALL_UNITS.items():
+    choicelist = type(choicelist_name, (Units, ), {'app_label': 'measurements'})
+    locals()[choicelist_name] = choicelist
+    add = locals()[choicelist_name].add_item
 
     TEMP_DICT = dict()
     for alias, symbol in measurement.get_aliases().items():
@@ -35,7 +48,9 @@ for choicelist, measurement in ALL_UNITS.items():
         TEMP_DICT[symbol] = alias
 
     for symbol, alias in TEMP_DICT.items():
-        add(symbol, _(alias), symbol)
+        add(symbol, _(alias), symbol, measurement_name=measurement.__name__)
+        s = choicelist_name.lower()[:-1] + '_' + symbol
+        AllUnits.add_item(s, _(alias), s, choicelist_class=choicelist)
 
     TEMP_DICT.clear()
 
