@@ -11,6 +11,7 @@ from lino.mixins import Hierarchical
 from lino.mixins.duplicable import Duplicable
 from lino.utils.mldbc.mixins import BabelNamed
 from lino.modlib.memo.mixins import BabelPreviewable
+from lino.modlib.memo.mixins import MemoReferrable
 
 from lino_xl.lib.vat.choicelists import VatClasses
 
@@ -54,7 +55,7 @@ class Categories(ProductsTable):
     ProductsByCategory
     """
 
-class Product(BabelNamed, BabelPreviewable, Duplicable):
+class Product(BabelNamed, BabelPreviewable, Duplicable, MemoReferrable):
 
     class Meta:
         app_label = 'products'
@@ -62,6 +63,8 @@ class Product(BabelNamed, BabelPreviewable, Duplicable):
         verbose_name_plural = _("Products")
         abstract = dd.is_abstract_model(__name__, 'Product')
 
+    memo_command = 'product'
+
     category = dd.ForeignKey(
         'products.Category', verbose_name=_("Category"),
         blank=True, null=True)
@@ -235,15 +238,15 @@ def inject_pricefactor_fields(sender, **kw):
 
 
 
-@dd.receiver(dd.post_startup)
-def setup_memo_commands(sender=None, **kwargs):
-    # See :doc:`/specs/memo`
-
-    if not sender.is_installed('memo'):
-        return
-
-    Product = sender.models.products.Product
-    mp = sender.plugins.memo.parser
-
-    mp.register_django_model(
-        'product', Product, title=lambda obj: str(obj.name))
+# @dd.receiver(dd.post_startup)
+# def setup_memo_commands(sender=None, **kwargs):
+#     # See :doc:`/specs/memo`
+#
+#     if not sender.is_installed('memo'):
+#         return
+#
+#     Product = sender.models.products.Product
+#     mp = sender.plugins.memo.parser
+#
+#     mp.register_django_model(
+#         'product', Product, title=lambda obj: str(obj.name))
