@@ -20,7 +20,11 @@ def objects():
     from datetime import date
     Report = rt.models.sheets.Report
     AccountingPeriod = rt.models.ledger.AccountingPeriod
-    ses = rt.login("robin")
+    try:
+        ses = rt.login("robin")
+    except rt.models.users.User.DoesNotExist:
+        print("20220621 no robin in ", rt.models.users.User.objects.all())
+        raise
     for year in range(dd.plugins.ledger.start_year, dd.today().year+1):
         sp = AccountingPeriod.get_default_for_date(date(year, 1, 1))
         ep = AccountingPeriod.get_default_for_date(date(year, 12, 31))
