@@ -73,7 +73,7 @@ class VatColumn(dd.Choice):
     common_account = None
 
     def __init__(self, value, text, common_account=None):
-        super(VatColumn, self).__init__(value, text)
+        super().__init__(value, text)
         self.common_account = common_account
 
 
@@ -102,7 +102,7 @@ class VatRegime(dd.Choice):
     # item_vat = True  # 20200521 no longer used
 
     def __init__(self, value, text, name, vat_area=None, item_vat=True, needs_vat_id=False):
-        super(VatRegime, self).__init__(value, text, name)
+        super().__init__(value, text, name)
         self.vat_area = vat_area
         self.needs_vat_id = needs_vat_id
         # self.item_vat = item_vat
@@ -170,7 +170,7 @@ class DeclarationField(dd.Choice):
         name = "F" + value
         # text = string_concat("[{}] ".format(value), text)
         self.help_text = text
-        super(DeclarationField, self).__init__(
+        super().__init__(
             value, "[{}]".format(value), name, **kwargs)
 
         # self.is_base = is_base
@@ -258,7 +258,7 @@ class DeclarationField(dd.Choice):
             if len(self.exclude_vat_columns) == 0:
                 self.exclude_vat_columns = None
 
-        super(DeclarationField, self).attach(choicelist)
+        super().attach(choicelist)
 
 
     def get_model_field(self):
@@ -280,7 +280,7 @@ class DeclarationField(dd.Choice):
 class SumDeclarationField(DeclarationField):
 
     def __init__(self, *args, **kwargs):
-        super(SumDeclarationField, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         if self.is_payable:
             raise Exception("SumDeclarationField may not be payable")
 
@@ -463,7 +463,7 @@ class VatRule(dd.Choice):
         if vat_returnable_account:
             kw.update(vat_returnable_account=vat_returnable_account)
         # text = "{trade_type} {vat_area} {vat_class} {rate}".format(**kw)
-        super(VatRule, self).__init__(None, None, **kw)
+        super().__init__(None, None, **kw)
 
     def __str__(rule):
         lst = []
@@ -907,7 +907,7 @@ class VatSubjectable(dd.Model):
             return VatRegimes.get_choices_for_country(country)
 
         def full_clean(self):
-            super(VatSubjectable, self).full_clean()
+            super().full_clean()
             self.vid_manager.sanitize()
 
         @property
