@@ -1,15 +1,10 @@
-# Copyright 2017 Rumma & Ko Ltd
+# Copyright 2017-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Adds voting functionality.
 
-.. autosummary::
-   :toctree:
+See :doc:`/plugins/votes`.
 
-    choicelists
-    actions
-    mixins
-    fixtures.demo2
 
 """
 
@@ -24,10 +19,18 @@ class Plugin(ad.Plugin):
     ## settings
     votable_model = 'tickets.Ticket'
     """The things we are voting about. A string referring to the model
-    which represents a votable in your application.  Default value is
-    ``'tickets.Ticket'`` (referring to
-    :class:`lino_xl.lib.tickets.models.Ticket`).
+    that represents a votable in your application.
 
+    Default value is ``'tickets.Ticket'`` (referring to
+    :class:`lino_xl.lib.tickets.Ticket`).
+
+    """
+
+    use_candidatures = False
+    """
+    Whether to use votes for implementing a kind of polling: when somebody posts
+    a ticket, other users are asked to vote on it, deciding whether they take it
+    or not.
     """
 
     def on_site_startup(self, site):
@@ -40,11 +43,12 @@ class Plugin(ad.Plugin):
         # mg = site.plugins[self.votable_model._meta.app_label]
         # mg = site.plugins.office
         m = m.add_menu(mg.app_label, mg.verbose_name)
-        m.add_action('votes.MyInvitations')
-        m.add_action('votes.MyTasks')
-        m.add_action('votes.MyOffers')
-        m.add_action('votes.MyWatched')
-        # m.add_action('votes.MyVotes')
+        if self.use_candidatures:
+            m.add_action('votes.MyInvitations')
+            m.add_action('votes.MyTasks')
+            m.add_action('votes.MyOffers')
+            m.add_action('votes.MyWatched')
+            # m.add_action('votes.MyVotes')
 
     def setup_explorer_menu(self, site, user_type, m):
         mg = self.get_menu_group()
@@ -54,7 +58,7 @@ class Plugin(ad.Plugin):
         m.add_action('votes.VoteStates')
 
     def get_dashboard_items(self, user):
-        if user.is_authenticated:
+        if self.use_candidatures and user.is_authenticated:
             yield self.site.models.votes.MyInvitations
             yield self.site.models.votes.MyTasks
             # yield self.site.models.votes.MyOffers
