@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2016-2021 Rumma & Ko Ltd
+# Copyright 2016-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.db import models
@@ -19,6 +19,7 @@ from .roles import VotesUser, VotesStaff
 from .choicelists import VoteStates, VoteEvents  # , VoteViews
 from .choicelists import Ratings
 from .actions import EditVote
+from lino.core import constants
 
 config = dd.plugins.votes
 
@@ -279,7 +280,7 @@ class AllVotes(Votes):
 #     label = _("Votes")
 #     master_key = 'project'
 #     column_names = 'votable user workflow_buttons *'
-#     display_mode_main = 'summary'
+#     display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
 #     stay_in_grid = True
 
 
@@ -343,7 +344,7 @@ class VotesByVotable(Votes):
     column_names = 'user workflow_buttons mail_mode *'
     # show_detail_navigator = False
     # hide_top_toolbar = True
-    display_mode_main = 'summary'
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY),)
     # exclude_vote_states = 'author'
     stay_in_grid = True
 
