@@ -641,10 +641,23 @@ if False:  # works, but is not useful
 
 
 from lino.modlib.checkdata.choicelists import Checker
-class TicketSessionsChecker(Checker):
-    """
+class SessionChecker(Checker):
+    model = Session
+    verbose_name = _("Check the computed duration of sessions.")
 
-    """
+    def get_checkdata_problems(self, obj, fix=False):
+        computed_duration = obj.compute_duration()
+        if str(obj.computed_duration) != str(computed_duration):
+            yield (True, _("Duration is {0} but should be {1}").format(
+                str(obj.computed_duration), str(computed_duration)))
+            if fix:
+                obj.computed_duration = computed_duration
+                obj.full_clean()
+                obj.save()
+
+SessionChecker.activate()
+
+class TicketSessionsChecker(Checker):
     model = dd.plugins.working.ticket_model
     verbose_name = _("Check the fixed_since field of tickets.")
 
