@@ -124,7 +124,7 @@ class Sessions(dd.Table):
 
     @classmethod
     def get_simple_parameters(cls):
-        s = list(super(Sessions, cls).get_simple_parameters())
+        s = list(super().get_simple_parameters())
         s += ['session_type', 'ticket']
         return s
 
@@ -136,7 +136,7 @@ class Sessions(dd.Table):
 
     @classmethod
     def get_request_queryset(self, ar):
-        qs = super(Sessions, self).get_request_queryset(ar)
+        qs = super().get_request_queryset(ar)
         pv = ar.param_values
         ce = pv.observed_event
         if ce is not None:
@@ -244,7 +244,7 @@ class MySessionsByDate(MySessions):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(MySessionsByDate, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(start_date=dd.today())
         kw.update(end_date=dd.today())
         return kw
@@ -441,7 +441,7 @@ class SessionsByReport(Sessions, DurationReport):
 
     @classmethod
     def get_row_by_pk(cls, ar, pk): # fixes #2434
-        obj = super(SessionsByReport, cls).get_row_by_pk(ar, pk)
+        obj = super().get_row_by_pk(ar, pk)
         if obj is not None:
             load_sessions(obj, [obj])
         return obj
@@ -458,7 +458,7 @@ class SessionsByReport(Sessions, DurationReport):
         spv.update(user=mi.user)
         ar.param_values.update(spv)
 
-        qs = super(SessionsByReport, self).get_request_queryset(ar)
+        qs = super().get_request_queryset(ar)
         for obj in qs:
             load_sessions(obj, [obj])
             # obj._invested_time = compute_invested_time(
@@ -504,7 +504,7 @@ class TicketsByReport(Tickets, DurationReport):
         spv = dict(start_date=mi.start_date, end_date=mi.end_date)
         spv.update(observed_event=dd.PeriodEvents.started)
         spv.update(user=mi.user)
-        qs = super(TicketsByReport, self).get_request_queryset(ar)
+        qs = super().get_request_queryset(ar)
         for obj in qs:
             sar = SessionsByTicket.request(
                 master_instance=obj, param_values=spv)
@@ -677,6 +677,7 @@ class SummariesByUser(UserSummaries):
 # class WorkedHours(Days, dd.VentilatingTable):
 # class WorkedHours(CalendarView):
 # class WorkedHours(ParameterClone, DayNavigator, dd.VentilatingTable):
+# class WorkedHours(DayNavigator, dd.VentilatingTable):
 class WorkedHours(DaysTable, dd.VentilatingTable):
     label = _("Worked hours")
     # parameters = dict()
@@ -687,6 +688,7 @@ class WorkedHours(DaysTable, dd.VentilatingTable):
     detail_layout = 'working.DayDetail'
     # navigation_mode = "day"  # "day" or "week" or "month"
     params_layout = "user start_date end_date"
+    # navigation_mode = "day"  # "day" or "week" or "month"
 
     # parameters = Sessions.parameters
     # params_layout = Sessions.params_layout
@@ -784,8 +786,13 @@ class MySessionsByDay(MySessionsByDate):
         pv = ar.param_values
         pv.update(start_date=mi.date, end_date=mi.date)
         pv.update(observed_event=dd.PeriodEvents.started)
-        if mi.ar is not None:
-            pv.update(user=mi.ar.get_user() if (mi.ar.param_values is None or
-                                                mi.ar.param_values.user is None
-                                                )else mi.ar.param_values.user)
-        return super(MySessionsByDay, cls).get_request_queryset(ar)
+        if mi.ar is None:
+            return []
+        if mi.ar.param_values is None or mi.ar.param_values.user is None:
+            u = mi.ar.get_user()
+        else:
+            u = mi.ar.param_values.user
+        if u.is_anonymous:
+            return []
+        pv.update(user=u)
+        return super().get_request_queryset(ar)
